@@ -2,12 +2,15 @@ import torch
 
 import numpy as np
 
+from PIL import Image
+from typing import List
 from typing import Callable
 from typing import Optional
 from cftool.array import to_torch
 
 from ...protocol import IImageExtractor
 from ...protocol import ImageFolderLatentResponse
+from ...cv.utils import predict_paths
 from ...cv.utils import predict_folder
 from ...cv.pipeline import CVPipeline
 from ....data import TensorData
@@ -15,6 +18,7 @@ from ....types import texts_type
 from ....protocol import IInference
 from ....constants import INPUT_KEY
 from ....constants import LATENT_KEY
+from ....misc.toolkit import eval_context
 from ....models.nlp.tokenizers import ITokenizer
 from ....models.multimodal.clip import CLIP
 
@@ -52,8 +56,7 @@ class CLIPExtractor(IImageExtractor):
     ) -> np.ndarray:
         if isinstance(texts, str):
             texts = [texts]
-        text_arrays = [self.tokenizer.tokenize(t) for t in texts]
-        texts_tensor = to_torch(np.vstack(text_arrays))
+        texts_tensor = to_torch(self.tokenizer.tokenize(texts))
         loader = TensorData(texts_tensor, batch_size=batch_size).get_loaders()[0]
         original_forward = self.clip.forward
         self.clip.forward = lambda _, batch, *s, **kws: self.text_forward_fn(batch)  # type: ignore
@@ -62,6 +65,32 @@ class CLIPExtractor(IImageExtractor):
         self.clip.forward = original_forward  # type: ignore
         return outputs.forward_results[LATENT_KEY]
 
+    def get_image_latent(self, image: Image.Image) -> np.ndarray:
+        inp = self.transform(image)[None].to(self.clip.device)
+        with eval_context(self.clip):
+            return self.clip.encode_image(inp).cpu().numpy()
+
+    def get_paths_latent(
+        self,
+        image_paths: List[str],
+        *,
+        batch_size: int = 64,
+        num_workers: int = 0,
+        use_tqdm: bool = True,
+    ) -> np.ndarray:
+        original_forward = self.clip.forward
+        self.clip.forward = lambda _, batch, *s, **kws: self.image_forward_fn(batch)  # type: ignore
+        results = predict_paths(
+            self.m,
+            image_paths,
+            batch_size=batch_size,
+            num_workers=num_workers,
+            transform=self.transform,
+            use_tqdm=use_tqdm,
+        )
+        self.clip.forward = original_forward  # type: ignore
+        return results.outputs[LATENT_KEY]
+
     def get_folder_latent(
         self,
         src_folder: str,
